@@ -256,6 +256,18 @@ PREMADE_REPORTS = [
             "eventName",
         ],
     },
+    {
+        "name": "conversions_report",
+        "metrics": [
+            "conversions",
+            "totalUsers",
+            "totalRevenue",
+        ],
+        "dimensions": [
+            "date",
+            "eventName",
+        ],
+    },
     {
         "name": "page_title_and_screen_class_report",
         "metrics": [
@@ -448,6 +460,17 @@ PREMADE_REPORTS = [
             "itemBrand",
         ],
     },
+    {
+        "name": "in_app_purchases",
+        "metrics": [
+            "itemsPurchased",
+            "itemRevenue",
+        ],
+        "dimensions": [
+            "date",
+            "itemId",
+        ],
+    },
     {
         "name": "publisher_ads_ad_unit_report",
         "metrics": [
